/* File name suffixes.  */
S_(BINPOLICY, "/policy/policy")
S_(CONTEXTS_DIR, "/contexts")
S_(FILE_CONTEXTS, "/contexts/files/file_contexts")
S_(DEFAULT_CONTEXTS, "/contexts/default_contexts")
S_(USER_CONTEXTS, "/contexts/users/")
S_(FAILSAFE_CONTEXT, "/contexts/failsafe_context")
S_(DEFAULT_TYPE, "/contexts/default_type")
S_(BOOLEANS, "/booleans")
S_(MEDIA_CONTEXTS, "/contexts/files/media")
S_(REMOVABLE_CONTEXT, "/contexts/removable_context")
S_(CUSTOMIZABLE_TYPES, "/contexts/customizable_types")
S_(USERS_DIR, "/users/")
